@@ -1,5 +1,7 @@
+import datetime
 import uuid
 
+import django.http.request
 from django.conf import settings
 from django.contrib import admin, messages
 from django.http import HttpResponse
@@ -84,8 +86,14 @@ class QRCodeAdmin(admin.ModelAdmin):
     get_code_url.short_description = 'Code url'
 
     def download_codes_action(self, request, queryset):
+        """
+
+        :type queryset: django.db.models.query.QuerySet
+        :type request: django.http.request.HttpRequest
+        """
         pks = [str(x.pk) for x in queryset.all()]
-        url = '%s?codes=%s' % (reverse('admin:admin_qr_download'), ','.join(pks))
+        url = '%s' % (reverse('admin:admin_qr_download'),)
+        request.session['codes_to_download'] = pks
         return redirect(url)
 
     download_codes_action.short_description = 'Download codes'
@@ -130,17 +138,22 @@ class QRCodeAdmin(admin.ModelAdmin):
 
         :type request: django.http.HttpRequest
         """
-        pks = [int(x) for x in request.GET['codes'].split(',')]
-        if request.user.is_superuser:
-            codes = QRCode.objects.filter(pk__in=pks).all()
-        else:
-            codes = QRCode.objects.filter(pk__in=pks, department__in=request.user.departments.all()).all()
         if request.method == 'POST':
+            download = request.GET['download']
+            print(download)
+            pks = [int(x) for x in download.split(',')]
+            print(pks)
+            if request.user.is_superuser:
+                codes = QRCode.objects.filter(pk__in=pks).all()
+            else:
+                codes = QRCode.objects.filter(pk__in=pks, department__in=request.user.departments.all()).all()
             form = QrGenerateForm(data=request.POST)
             if form.is_valid():
+                print(codes)
                 zf = generate_qr_zip(codes, form)
                 resp = HttpResponse(zf, content_type="application/x-zip-compressed")
-                resp['Content-Disposition'] = f'attachment; filename=generated_codes.zip'
+                resp[
+                    'Content-Disposition'] = f'attachment; filename=generated_codes-{download.replace(",", "_")[:20]}.zip'
                 return resp
             else:
                 context = dict(
@@ -152,6 +165,11 @@ class QRCodeAdmin(admin.ModelAdmin):
                 )
                 return render(request, 'qrtoolkit_core/qrcode/download.html', context=context)
         else:
+            pks = request.session.get('codes_to_download')
+            if request.user.is_superuser:
+                codes = QRCode.objects.filter(pk__in=pks).all()
+            else:
+                codes = QRCode.objects.filter(pk__in=pks, department__in=request.user.departments.all()).all()
             context = dict(
                 self.admin_site.each_context(request),
                 is_nav_sidebar_enabled=False,
