@@ -55,7 +55,7 @@ QR_MODE_HELP_TEXT = """
 Sets the mode this code is in.<br/>
 Kiosk Mode: Show buttons to choose a link from<br/>
 Redirect Mode: Instantly redirects to the url with the highest priority.<br/>
-Information Page Mode: Show basic info with links to different urls
+Information Page Mode: Show basic info with links to different urls.
 """
 
 
@@ -103,6 +103,18 @@ class QRCode(models.Model):
         return f'{self.title}'
 
 
+class ApiCall(models.Model):
+    url = models.URLField()
+    code = models.ForeignKey(QRCode, on_delete=models.CASCADE, related_name='api_calls')
+    payload = models.TextField()
+
+
+class Header(models.Model):
+    api_call = models.ForeignKey(ApiCall, on_delete=models.CASCADE, related_name='headers')
+    key = models.CharField(max_length=128)
+    value = models.CharField(max_length=128)
+
+
 def random_string():
     alphabet = string.ascii_lowercase + string.digits
     return ''.join(random.choices(alphabet, k=8))
